@@ -90,10 +90,11 @@ _GJS_CAIRO_CONTEXT_DEFINE_FUNC_END
         JS::RootedObject array(context, JS::NewArrayObject(context, 2));    \
         if (!array)                                                         \
             return false;                                                   \
-        JS::RootedValue r(context, JS::NumberValue(arg1));                  \
+        JS::RootedValue r{context,                                          \
+                          JS::NumberValue(JS::CanonicalizeNaN(arg1))};      \
         if (!JS_SetElement(context, array, 0, r))                           \
             return false;                                                   \
-        r.setNumber(arg2);                                                  \
+        r.setNumber(JS::CanonicalizeNaN(arg2));                             \
         if (!JS_SetElement(context, array, 1, r))                           \
             return false;                                                   \
         argv.rval().setObject(*array);                                      \
@@ -109,10 +110,11 @@ _GJS_CAIRO_CONTEXT_DEFINE_FUNC_END
         JS::RootedObject array(context, JS::NewArrayObject(context, 2)); \
         if (!array)                                                      \
             return false;                                                \
-        JS::RootedValue r(context, JS::NumberValue(arg1));               \
+        JS::RootedValue r{context,                                       \
+                          JS::NumberValue(JS::CanonicalizeNaN(arg1))};   \
         if (!JS_SetElement(context, array, 0, r))                        \
             return false;                                                \
-        r.setNumber(arg2);                                               \
+        r.setNumber(JS::CanonicalizeNaN(arg2));                          \
         if (!JS_SetElement(context, array, 1, r))                        \
             return false;                                                \
         argv.rval().setObject(*array);                                   \
@@ -128,16 +130,17 @@ _GJS_CAIRO_CONTEXT_DEFINE_FUNC_END
         JS::RootedObject array(context, JS::NewArrayObject(context, 4)); \
         if (!array)                                                      \
             return false;                                                \
-        JS::RootedValue r(context, JS::NumberValue(arg1));               \
+        JS::RootedValue r{context,                                       \
+                          JS::NumberValue(JS::CanonicalizeNaN(arg1))};   \
         if (!JS_SetElement(context, array, 0, r))                        \
             return false;                                                \
-        r.setNumber(arg2);                                               \
+        r.setNumber(JS::CanonicalizeNaN(arg2));                          \
         if (!JS_SetElement(context, array, 1, r))                        \
             return false;                                                \
-        r.setNumber(arg3);                                               \
+        r.setNumber(JS::CanonicalizeNaN(arg3));                          \
         if (!JS_SetElement(context, array, 2, r))                        \
             return false;                                                \
-        r.setNumber(arg4);                                               \
+        r.setNumber(JS::CanonicalizeNaN(arg4));                          \
         if (!JS_SetElement(context, array, 3, r))                        \
             return false;                                                \
         argv.rval().setObject(*array);                                   \
@@ -149,7 +152,7 @@ _GJS_CAIRO_CONTEXT_DEFINE_FUNC_BEGIN(method)                               \
     double ret;                                                            \
    _GJS_CAIRO_CONTEXT_CHECK_NO_ARGS(method)                                \
     ret = cfunc(cr);                                                       \
-    argv.rval().setNumber(ret);                                            \
+    argv.rval().setNumber(JS::CanonicalizeNaN(ret));                       \
 _GJS_CAIRO_CONTEXT_DEFINE_FUNC_END
 
 #define _GJS_CAIRO_CONTEXT_DEFINE_FUNC1(method, cfunc, fmt, t1, n1)        \
